# UI/UX Feedback

**ID:** Feedback-20260222-110609
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-22 11:09:21

## Selected Elements

- `{'selector': 'div.deliverable-card-header', 'parents': ['div.workflow-panel-body', 'div.deliverables-area', 'div.deliverables-grid', 'div.deliverable-card.folder-type']}`

## Feedback

let's create a CR, 1. background of folder should not be the same as file. 2. let's not use inline folder tree, remove all the code related to inline folder tree. instead, when we click on it, we should have a modal window, leftside is a folder tree, right side is file preview, just like the link an idea function in the compose ida modal window(without editing functions)

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260222-110609/page-screenshot.png)
